@@ -89,7 +89,8 @@ Workspace <- R6::R6Class("Workspace",
         global_env = list(nonfuncts = character(0),
                           functs = character(0),
                           signatures = list(),
-                          formals = list()),
+                          formals = list(),
+                          definitions = DefinitionCache$new()),
 
         initialize = function() {
             for (pkgname in self$loaded_packages) {
@@ -188,7 +189,42 @@ Workspace <- R6::R6Class("Workspace",
             }
         },
 
-        load_to_global = function(parse_result) {
+        get_definition = function(topic) {
+            self$global_env$definitions$get(topic)
+        },
+
+        get_definitions_for_uri = function(uri) {
+            self$global_env$definitions$get_functs_for_uri(uri)
+        },
+
+        get_definitions_for_query = function(query) {
+            self$global_env$definitions$filter(query)
+        },
+
+        get_code = function(topic, pkg = NULL) {
+            if (is.null(pkg) || is.na(pkg)) {
+                logger$info("pkg guess !")
+                pkg <- self$guess_package(topic)
+            }
+            logger$info("pkg:", pkg)
+
+            if (is.null(pkg)) {
+                return(NULL)
+            } else {
+                code <- utils::getFromNamespace(topic, pkg)
+            }
+            if (length(code) > 0) {
+                code <- repr::repr_text(code)
+                # reorganize the code
+                code <- stringr::str_split(code, "\n")[[1]]
+                code[1] <- paste(topic, "<-", code[1])
+                enc2utf8(code[!grepl("<bytecode|<environment", code)])
+            } else {
+                NULL
+            }
+        },
+
+        load_to_global = function(parse_result, uri) {
             self$global_env$nonfuncts <- unique(
                 c(self$global_env$nonfuncts, parse_result$nonfuncts))
             self$global_env$functs <- unique(
@@ -197,6 +233,7 @@ Workspace <- R6::R6Class("Workspace",
                 self$global_env$signatures, parse_result$signatures)
             self$global_env$formals <- merge_list(
                 self$global_env$formals, parse_result$formals)
+            self$global_env$definitions$update(uri, parse_result$definition_ranges)
         }
     )
 )
@@ -319,7 +356,7 @@ process_sync_out <- function(self) {
                     self$workspace$load_package(package)
                 }
 
-                self$workspace$load_to_global(parse_result)
+                self$workspace$load_to_global(parse_result, uri)
             }
 
             # cleanup
